@@ -910,6 +910,13 @@ def test_weighted_reduction():
         da.reduction(dx, w_sum, np.sum, weights=[[[2]]])
 
 
+def test_cumreduction_no_rechunk_on_1d_array():
+    x = da.ones((5,))
+    y = da.cumsum(x)
+    no_rechunk = "rechunk" not in str(dict(y.__dask_graph__()))
+    assert no_rechunk
+
+
 @pytest.mark.parametrize("axis", [3, 0, [1, 3]])
 @pytest.mark.parametrize("q", [0.75, [0.75], [0.75, 0.4]])
 @pytest.mark.parametrize("rechunk", [True, False])
@@ -918,6 +925,8 @@ def test_nanquantile(rechunk, q, axis):
     arr = np.random.randn(*shape)
     indexer = np.random.randint(0, 10, size=shape)
     arr[indexer >= 8] = np.nan
+    arr[:, :, :, 1] = 1
+    arr[1, :, :, :] = 1
 
     darr = da.from_array(arr, chunks=(2, 3, 4, (5 if rechunk else -1)))
     assert_eq(da.nanquantile(darr, q, axis=axis), np.nanquantile(arr, q, axis=axis))
@@ -957,6 +966,24 @@ def test_quantile(rechunk, q, axis):
     )
 
 
+@pytest.mark.parametrize("func", [da.quantile, da.nanquantile, da.nanpercentile])
+def test_quantile_func_family_with_axis_none(func):
+
+    # Check that these functions raise a NotImplementedError
+    # when axis=None and more than one chunk is present
+    # along at least one dimension
+    darr = da.ones((3, 3), chunks=(2, 2))
+    with pytest.raises(
+        NotImplementedError, match="The full algorithm is difficult to do in parallel"
+    ):
+        func(darr, 0.5, axis=None)
+
+    # Check that the functions behave as expected
+    # when axis=None and the array is a single chunk
+    darr = da.from_array([-1, 0, 1])
+    assert_eq(func(darr, 0.0, axis=None), -1.0)
+
+
 def test_nanquantile_all_nan():
     shape = 10, 15, 20, 15
     arr = np.random.randn(*shape)
